@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2014 Pranav Kant
- * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2012 – 2016 Red Hat, Inc.
  * Copyright © 2014 Saurav Agarwalla
  *
  * This program is free software; you can redistribute it and/or
@@ -61,8 +61,9 @@ struct _PhotosEmbedSearchState
   gchar *str;
 };
 
-struct _PhotosEmbedPrivate
+struct _PhotosEmbed
 {
+  GtkBox parent_instance;
   GAction *search_action;
   GIOExtensionPoint *extension_point;
   GtkWidget *collections;
@@ -87,8 +88,13 @@ struct _PhotosEmbedPrivate
   guint load_show_id;
 };
 
+struct _PhotosEmbedClass
+{
+  GtkBoxClass parent_class;
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosEmbed, photos_embed, GTK_TYPE_BOX);
+
+G_DEFINE_TYPE (PhotosEmbed, photos_embed, GTK_TYPE_BOX);
 
 
 static void photos_embed_search_changed (PhotosEmbed *self);
@@ -97,34 +103,28 @@ static void photos_embed_search_changed (PhotosEmbed *self);
 static void
 photos_embed_block_search_changed (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
-  g_signal_handlers_block_by_func (priv->src_mngr, photos_embed_search_changed, self);
-  g_signal_handlers_block_by_func (priv->srch_mngr, photos_embed_search_changed, self);
-  g_signal_handlers_block_by_func (priv->srch_cntrlr, photos_embed_search_changed, self);
+  g_signal_handlers_block_by_func (self->src_mngr, photos_embed_search_changed, self);
+  g_signal_handlers_block_by_func (self->srch_mngr, photos_embed_search_changed, self);
+  g_signal_handlers_block_by_func (self->srch_cntrlr, photos_embed_search_changed, self);
 }
 
 
 static void
 photos_embed_unblock_search_changed (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
-  g_signal_handlers_unblock_by_func (priv->src_mngr, photos_embed_search_changed, self);
-  g_signal_handlers_unblock_by_func (priv->srch_mngr, photos_embed_search_changed, self);
-  g_signal_handlers_unblock_by_func (priv->srch_cntrlr, photos_embed_search_changed, self);
+  g_signal_handlers_unblock_by_func (self->src_mngr, photos_embed_search_changed, self);
+  g_signal_handlers_unblock_by_func (self->srch_mngr, photos_embed_search_changed, self);
+  g_signal_handlers_unblock_by_func (self->srch_cntrlr, photos_embed_search_changed, self);
 }
 
 
 static void
 photos_embed_clear_load_timer (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
-  if (priv->load_show_id != 0)
+  if (self->load_show_id != 0)
     {
-      g_source_remove (priv->load_show_id);
-      priv->load_show_id = 0;
+      g_source_remove (self->load_show_id);
+      self->load_show_id = 0;
     }
 }
 
@@ -132,37 +132,34 @@ photos_embed_clear_load_timer (PhotosEmbed *self)
 static void
 photos_embed_clear_search (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
-  g_clear_object (&priv->search_state.search_type);
-  g_clear_object (&priv->search_state.source);
-  g_clear_pointer (&priv->search_state.str, g_free);
+  g_clear_object (&self->search_state.search_type);
+  g_clear_object (&self->search_state.source);
+  g_clear_pointer (&self->search_state.str, g_free);
 }
 
 
 static GtkWidget*
 photos_embed_get_view_container_from_mode (PhotosEmbed *self, PhotosWindowMode mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GtkWidget *view_container;
 
   switch (mode)
     {
     case PHOTOS_WINDOW_MODE_COLLECTIONS:
-      view_container = priv->collections;
+      view_container = self->collections;
       break;
 
     case PHOTOS_WINDOW_MODE_FAVORITES:
-      view_container = priv->favorites;
+      view_container = self->favorites;
       break;
 
     case PHOTOS_WINDOW_MODE_OVERVIEW:
-      view_container = priv->overview;
+      view_container = self->overview;
       break;
 
 
     case PHOTOS_WINDOW_MODE_SEARCH:
-      view_container = priv->search;
+      view_container = self->search;
       break;
 
     case PHOTOS_WINDOW_MODE_NONE:
@@ -179,13 +176,12 @@ photos_embed_get_view_container_from_mode (PhotosEmbed *self, PhotosWindowMode m
 static void
 photos_embed_activate_result (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GtkTreeIter iter;
   GtkListStore *store;
   GtkWidget *view_container;
   PhotosWindowMode mode;
 
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   view_container = photos_embed_get_view_container_from_mode (self, mode);
   store = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
 
@@ -195,8 +191,8 @@ photos_embed_activate_result (PhotosEmbed *self)
       gchar *id;
 
       gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, PHOTOS_VIEW_MODEL_URN, &id, -1);
-      item = photos_base_manager_get_object_by_id (priv->item_mngr, id);
-      photos_base_manager_set_active_object (priv->item_mngr, item);
+      item = photos_base_manager_get_object_by_id (self->item_mngr, id);
+      photos_base_manager_set_active_object (self->item_mngr, item);
       g_free (id);
     }
 }
@@ -205,42 +201,40 @@ photos_embed_activate_result (PhotosEmbed *self)
 static void
 photos_embed_restore_search (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GVariant *state;
 
-  if (!priv->search_state.saved)
+  if (!self->search_state.saved)
     return;
 
-  photos_base_manager_set_active_object (priv->src_mngr, priv->search_state.source);
-  photos_base_manager_set_active_object (priv->srch_mngr, priv->search_state.search_type);
-  photos_search_controller_set_string (priv->srch_cntrlr, priv->search_state.str);
-  priv->search_state.saved = FALSE;
+  photos_base_manager_set_active_object (self->src_mngr, self->search_state.source);
+  photos_base_manager_set_active_object (self->srch_mngr, self->search_state.search_type);
+  photos_search_controller_set_string (self->srch_cntrlr, self->search_state.str);
+  self->search_state.saved = FALSE;
 
   photos_embed_clear_search (self);
 
   state = g_variant_new ("b", TRUE);
-  g_action_change_state (priv->search_action, state);
+  g_action_change_state (self->search_action, state);
 }
 
 
 static void
 photos_embed_save_search (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GVariant *state;
 
-  if (priv->search_state.saved)
+  if (self->search_state.saved)
     return;
 
   photos_embed_clear_search (self);
 
-  priv->search_state.source = g_object_ref (photos_base_manager_get_active_object (priv->src_mngr));
-  priv->search_state.search_type = g_object_ref (photos_base_manager_get_active_object (priv->srch_mngr));
-  priv->search_state.str = g_strdup (photos_search_controller_get_string (priv->srch_cntrlr));
-  priv->search_state.saved = TRUE;
+  self->search_state.source = g_object_ref (photos_base_manager_get_active_object (self->src_mngr));
+  self->search_state.search_type = g_object_ref (photos_base_manager_get_active_object (self->srch_mngr));
+  self->search_state.str = g_strdup (photos_search_controller_get_string (self->srch_cntrlr));
+  self->search_state.saved = TRUE;
 
   state = g_variant_new ("b", FALSE);
-  g_action_change_state (priv->search_action, state);
+  g_action_change_state (self->search_action, state);
 }
 
 
@@ -250,7 +244,7 @@ photos_embed_tracker_controllers_set_frozen (PhotosEmbed *self, gboolean frozen)
   GList *extensions;
   GList *l;
 
-  extensions = g_io_extension_point_get_extensions (self->priv->extension_point);
+  extensions = g_io_extension_point_get_extensions (self->extension_point);
   for (l = extensions; l != NULL; l = l->next)
     {
       GIOExtension *extension = (GIOExtension *) l->data;
@@ -273,7 +267,6 @@ photos_embed_tracker_controllers_set_frozen (PhotosEmbed *self, gboolean frozen)
 static void
 photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   PhotosBaseItem *active_collection;
 
   /* TODO: SearchController,
@@ -288,7 +281,7 @@ photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
    */
   photos_embed_tracker_controllers_set_frozen (self, TRUE);
 
-  active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (priv->item_mngr));
+  active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (self->item_mngr));
   if (old_mode == PHOTOS_WINDOW_MODE_SEARCH)
     {
       if (active_collection == NULL)
@@ -302,7 +295,7 @@ photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
        * around.
        */
       state = g_variant_new ("b", FALSE);
-      g_action_change_state (priv->search_action, state);
+      g_action_change_state (self->search_action, state);
     }
 
   /* This is not needed when activated from the search provider, or
@@ -317,29 +310,27 @@ photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
       view_container = photos_embed_get_view_container_from_mode (self, old_mode);
       current_path = photos_view_container_get_current_path (PHOTOS_VIEW_CONTAINER (view_container));
       model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-      photos_preview_view_set_model (PHOTOS_PREVIEW_VIEW (priv->preview), GTK_TREE_MODEL (model), current_path);
+      photos_preview_view_set_model (PHOTOS_PREVIEW_VIEW (self->preview), GTK_TREE_MODEL (model), current_path);
     }
 
   if (old_mode != PHOTOS_WINDOW_MODE_EDIT)
-    photos_preview_view_set_node (PHOTOS_PREVIEW_VIEW (priv->preview), NULL);
+    photos_preview_view_set_node (PHOTOS_PREVIEW_VIEW (self->preview), NULL);
 
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "preview");
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
+  gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "preview");
 }
 
 
 static void
 photos_embed_load_finished (PhotosEmbed *self, PhotosBaseItem *item, GeglNode *node)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   photos_embed_clear_load_timer (self);
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
 
   if (node == NULL)
     return;
 
-  photos_preview_view_set_node (PHOTOS_PREVIEW_VIEW (priv->preview), node);
+  photos_preview_view_set_node (PHOTOS_PREVIEW_VIEW (self->preview), node);
 
   /* TODO: set toolbar model */
 }
@@ -349,10 +340,9 @@ static gboolean
 photos_embed_load_show_timeout (gpointer user_data)
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
-  PhotosEmbedPrivate *priv = self->priv;
 
-  priv->load_show_id = 0;
-  photos_spinner_box_start (PHOTOS_SPINNER_BOX (priv->spinner_box));
+  self->load_show_id = 0;
+  photos_spinner_box_start (PHOTOS_SPINNER_BOX (self->spinner_box));
   g_object_unref (self);
   return G_SOURCE_REMOVE;
 }
@@ -362,7 +352,7 @@ static void
 photos_embed_load_started (PhotosEmbed *self, PhotosBaseItem *item)
 {
   photos_embed_clear_load_timer (self);
-  self->priv->load_show_id = g_timeout_add (400, photos_embed_load_show_timeout, g_object_ref (self));
+  self->load_show_id = g_timeout_add (400, photos_embed_load_show_timeout, g_object_ref (self));
 }
 
 
@@ -370,10 +360,9 @@ static void
 photos_embed_active_collection_changed (PhotosBaseManager *manager, PhotosBaseItem *collection, gpointer user_data)
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
-  PhotosEmbedPrivate *priv = self->priv;
   PhotosWindowMode mode;
 
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (mode != PHOTOS_WINDOW_MODE_SEARCH)
     return;
 
@@ -389,14 +378,14 @@ photos_embed_active_collection_changed (PhotosBaseManager *manager, PhotosBaseIt
 
       photos_embed_save_search (self);
 
-      search_type = PHOTOS_SEARCH_TYPE (photos_base_manager_get_active_object (priv->srch_mngr));
-      str = photos_search_controller_get_string (priv->srch_cntrlr);
+      search_type = PHOTOS_SEARCH_TYPE (photos_base_manager_get_active_object (self->srch_mngr));
+      str = photos_search_controller_get_string (self->srch_cntrlr);
       id = photos_filterable_get_id (PHOTOS_FILTERABLE (search_type));
 
       if (g_strcmp0 (str, "") != 0 || g_strcmp0 (id, "all") != 0)
         {
-          photos_base_manager_set_active_object_by_id (priv->srch_mngr, "all");
-          photos_search_controller_set_string (priv->srch_cntrlr, "");
+          photos_base_manager_set_active_object_by_id (self->srch_mngr, "all");
+          photos_search_controller_set_string (self->srch_cntrlr, "");
         }
     }
 }
@@ -411,113 +400,101 @@ photos_embed_fullscreen_changed (PhotosModeController *mode_cntrlr, gboolean ful
 static void
 photos_embed_notify_visible_child (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GtkWidget *visible_child;
   GVariant *state;
   PhotosWindowMode mode = PHOTOS_WINDOW_MODE_NONE;
 
-  visible_child = gtk_stack_get_visible_child (GTK_STACK (priv->stack));
-  if (visible_child == priv->overview)
+  visible_child = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  if (visible_child == self->overview)
     mode = PHOTOS_WINDOW_MODE_OVERVIEW;
-  else if (visible_child == priv->collections)
+  else if (visible_child == self->collections)
     mode = PHOTOS_WINDOW_MODE_COLLECTIONS;
-  else if (visible_child == priv->favorites)
+  else if (visible_child == self->favorites)
     mode = PHOTOS_WINDOW_MODE_FAVORITES;
 
   if (mode == PHOTOS_WINDOW_MODE_NONE)
     return;
 
-  if (!photos_main_toolbar_is_focus (PHOTOS_MAIN_TOOLBAR (priv->toolbar)))
+  if (!photos_main_toolbar_is_focus (PHOTOS_MAIN_TOOLBAR (self->toolbar)))
     {
       photos_embed_block_search_changed (self);
       state = g_variant_new ("b", FALSE);
-      g_action_change_state (priv->search_action, state);
+      g_action_change_state (self->search_action, state);
       photos_embed_unblock_search_changed (self);
     }
 
-  photos_mode_controller_set_window_mode (priv->mode_cntrlr, mode);
+  photos_mode_controller_set_window_mode (self->mode_cntrlr, mode);
 }
 
 
 static void
 photos_embed_prepare_for_collections (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   if (old_mode == PHOTOS_WINDOW_MODE_PREVIEW)
     photos_embed_tracker_controllers_set_frozen (self, FALSE);
 
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "collections");
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
+  gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "collections");
 }
 
 
 static void
 photos_embed_prepare_for_favorites (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   if (old_mode == PHOTOS_WINDOW_MODE_PREVIEW)
     photos_embed_tracker_controllers_set_frozen (self, FALSE);
 
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "favorites");
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
+  gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "favorites");
 }
 
 
 static void
 photos_embed_prepare_for_overview (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   if (old_mode == PHOTOS_WINDOW_MODE_PREVIEW)
     photos_embed_tracker_controllers_set_frozen (self, FALSE);
 
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "overview");
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
+  gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "overview");
 }
 
 
 static void
 photos_embed_prepare_for_search (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   if (old_mode == PHOTOS_WINDOW_MODE_PREVIEW)
     {
       PhotosBaseItem *active_collection;
 
-      active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (priv->item_mngr));
+      active_collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (self->item_mngr));
       if (active_collection == NULL)
         photos_embed_restore_search (self);
 
       photos_embed_tracker_controllers_set_frozen (self, FALSE);
     }
 
-  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "search");
+  photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
+  gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "search");
 }
 
 
 static void
 photos_embed_query_status_changed (PhotosEmbed *self, gboolean querying)
 {
-  PhotosEmbedPrivate *priv = self->priv;
-
   if (querying)
-    photos_spinner_box_start (PHOTOS_SPINNER_BOX (priv->spinner_box));
+    photos_spinner_box_start (PHOTOS_SPINNER_BOX (self->spinner_box));
   else
-    photos_spinner_box_stop (PHOTOS_SPINNER_BOX (priv->spinner_box));
+    photos_spinner_box_stop (PHOTOS_SPINNER_BOX (self->spinner_box));
 }
 
 
 static void
 photos_embed_row_changed (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   PhotosWindowMode mode;
 
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
 
   if (mode == PHOTOS_WINDOW_MODE_COLLECTIONS
       || mode == PHOTOS_WINDOW_MODE_FAVORITES
@@ -529,7 +506,7 @@ photos_embed_row_changed (PhotosEmbed *self)
 
       view_container = photos_embed_get_view_container_from_mode (self, mode);
       model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-      photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (priv->toolbar), PHOTOS_VIEW_MODEL (model));
+      photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (self->toolbar), PHOTOS_VIEW_MODEL (model));
     }
 }
 
@@ -537,7 +514,6 @@ photos_embed_row_changed (PhotosEmbed *self)
 static void
 photos_embed_search_changed (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv = self->priv;
   GObject *object;
   PhotosWindowMode mode;
   const gchar *search_type_id;
@@ -554,27 +530,27 @@ photos_embed_search_changed (PhotosEmbed *self)
    *  - when moving from search to preview or collection view
    *  - when in preview
    */
-  object = photos_base_manager_get_active_object (priv->item_mngr);
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  object = photos_base_manager_get_active_object (self->item_mngr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (mode == PHOTOS_WINDOW_MODE_SEARCH && object != NULL)
     return;
   if (mode == PHOTOS_WINDOW_MODE_PREVIEW)
     return;
 
-  object = photos_base_manager_get_active_object (priv->src_mngr);
+  object = photos_base_manager_get_active_object (self->src_mngr);
   source_id = photos_filterable_get_id (PHOTOS_FILTERABLE (object));
 
-  object = photos_base_manager_get_active_object (priv->srch_mngr);
+  object = photos_base_manager_get_active_object (self->srch_mngr);
   search_type_id = photos_filterable_get_id (PHOTOS_FILTERABLE (object));
 
-  str = photos_search_controller_get_string (priv->srch_cntrlr);
+  str = photos_search_controller_get_string (self->srch_cntrlr);
 
   if (g_strcmp0 (search_type_id, PHOTOS_SEARCH_TYPE_STOCK_ALL) == 0
       && g_strcmp0 (source_id, PHOTOS_SOURCE_STOCK_ALL) == 0
       && (str == NULL || str [0] == '\0'))
-    photos_mode_controller_go_back (priv->mode_cntrlr);
+    photos_mode_controller_go_back (self->mode_cntrlr);
   else
-    photos_mode_controller_set_window_mode (priv->mode_cntrlr, PHOTOS_WINDOW_MODE_SEARCH);
+    photos_mode_controller_set_window_mode (self->mode_cntrlr, PHOTOS_WINDOW_MODE_SEARCH);
 }
 
 
@@ -585,11 +561,10 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
                                   gpointer user_data)
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
-  PhotosEmbedPrivate *priv = self->priv;
   GtkListStore *model;
   GtkWidget *view_container;
 
-  photos_main_toolbar_reset_toolbar_mode (PHOTOS_MAIN_TOOLBAR (priv->toolbar));
+  photos_main_toolbar_reset_toolbar_mode (PHOTOS_MAIN_TOOLBAR (self->toolbar));
 
   switch (mode)
     {
@@ -627,7 +602,7 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
  set_toolbar_model:
   view_container = photos_embed_get_view_container_from_mode (self, mode);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-  photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (priv->toolbar), PHOTOS_VIEW_MODEL (model));
+  photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (self->toolbar), PHOTOS_VIEW_MODEL (model));
 }
 
 
@@ -635,17 +610,16 @@ static void
 photos_embed_dispose (GObject *object)
 {
   PhotosEmbed *self = PHOTOS_EMBED (object);
-  PhotosEmbedPrivate *priv = self->priv;
 
   photos_embed_clear_search (self);
 
-  g_clear_object (&priv->ntfctn_mngr);
-  g_clear_object (&priv->item_mngr);
-  g_clear_object (&priv->src_mngr);
-  g_clear_object (&priv->srch_mngr);
-  g_clear_object (&priv->mode_cntrlr);
-  g_clear_object (&priv->srch_cntrlr);
-  g_clear_object (&priv->trk_ovrvw_cntrlr);
+  g_clear_object (&self->ntfctn_mngr);
+  g_clear_object (&self->item_mngr);
+  g_clear_object (&self->src_mngr);
+  g_clear_object (&self->srch_mngr);
+  g_clear_object (&self->mode_cntrlr);
+  g_clear_object (&self->srch_cntrlr);
+  g_clear_object (&self->trk_ovrvw_cntrlr);
 
   /* GtkStack triggers notify::visible-child during dispose and this means that
    * we have to explicitly disconnect the signal handler before calling up to
@@ -654,10 +628,10 @@ photos_embed_dispose (GObject *object)
    *
    * See https://bugzilla.gnome.org/show_bug.cgi?id=749012
    */
-  if (priv->stack != NULL)
+  if (self->stack != NULL)
     {
-      g_signal_handlers_disconnect_by_func (priv->stack, photos_embed_notify_visible_child, self);
-      priv->stack = NULL;
+      g_signal_handlers_disconnect_by_func (self->stack, photos_embed_notify_visible_child, self);
+      self->stack = NULL;
     }
 
   G_OBJECT_CLASS (photos_embed_parent_class)->dispose (object);
@@ -667,7 +641,6 @@ photos_embed_dispose (GObject *object)
 static void
 photos_embed_init (PhotosEmbed *self)
 {
-  PhotosEmbedPrivate *priv;
   GApplication *app;
   GList *windows;
   GtkListStore *model;
@@ -676,139 +649,136 @@ photos_embed_init (PhotosEmbed *self)
   gboolean querying;
   const gchar *name;
 
-  self->priv = photos_embed_get_instance_private (self);
-  priv = self->priv;
-
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  priv->search_action = g_action_map_lookup_action (G_ACTION_MAP (app), "search");
+  self->search_action = g_action_map_lookup_action (G_ACTION_MAP (app), "search");
 
   gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
   gtk_widget_show (GTK_WIDGET (self));
 
-  priv->extension_point = g_io_extension_point_lookup (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME);
+  self->extension_point = g_io_extension_point_lookup (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME);
 
-  priv->selection_toolbar = photos_selection_toolbar_new ();
-  gtk_box_pack_end (GTK_BOX (self), priv->selection_toolbar, FALSE, FALSE, 0);
+  self->selection_toolbar = photos_selection_toolbar_new ();
+  gtk_box_pack_end (GTK_BOX (self), self->selection_toolbar, FALSE, FALSE, 0);
 
-  priv->stack_overlay = gtk_overlay_new ();
-  gtk_widget_show (priv->stack_overlay);
-  gtk_box_pack_end (GTK_BOX (self), priv->stack_overlay, TRUE, TRUE, 0);
+  self->stack_overlay = gtk_overlay_new ();
+  gtk_widget_show (self->stack_overlay);
+  gtk_box_pack_end (GTK_BOX (self), self->stack_overlay, TRUE, TRUE, 0);
 
-  priv->stack = gtk_stack_new ();
-  gtk_stack_set_homogeneous (GTK_STACK (priv->stack), TRUE);
-  gtk_stack_set_transition_type (GTK_STACK (priv->stack), GTK_STACK_TRANSITION_TYPE_CROSSFADE);
-  gtk_widget_show (priv->stack);
-  gtk_container_add (GTK_CONTAINER (priv->stack_overlay), priv->stack);
+  self->stack = gtk_stack_new ();
+  gtk_stack_set_homogeneous (GTK_STACK (self->stack), TRUE);
+  gtk_stack_set_transition_type (GTK_STACK (self->stack), GTK_STACK_TRANSITION_TYPE_CROSSFADE);
+  gtk_widget_show (self->stack);
+  gtk_container_add (GTK_CONTAINER (self->stack_overlay), self->stack);
 
-  priv->toolbar = photos_main_toolbar_new (GTK_OVERLAY (priv->stack_overlay));
-  photos_main_toolbar_set_stack (PHOTOS_MAIN_TOOLBAR (priv->toolbar), GTK_STACK (priv->stack));
+  self->toolbar = photos_main_toolbar_new (GTK_OVERLAY (self->stack_overlay));
+  photos_main_toolbar_set_stack (PHOTOS_MAIN_TOOLBAR (self->toolbar), GTK_STACK (self->stack));
   windows = gtk_application_get_windows (GTK_APPLICATION (app));
-  gtk_window_set_titlebar (GTK_WINDOW (windows->data), priv->toolbar);
-  searchbar = photos_main_toolbar_get_searchbar (PHOTOS_MAIN_TOOLBAR (priv->toolbar));
+  gtk_window_set_titlebar (GTK_WINDOW (windows->data), self->toolbar);
+  searchbar = photos_main_toolbar_get_searchbar (PHOTOS_MAIN_TOOLBAR (self->toolbar));
   g_signal_connect_swapped (searchbar, "activate-result", G_CALLBACK (photos_embed_activate_result), self);
 
-  priv->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
-  gtk_overlay_add_overlay (GTK_OVERLAY (priv->stack_overlay), priv->ntfctn_mngr);
+  self->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
+  gtk_overlay_add_overlay (GTK_OVERLAY (self->stack_overlay), self->ntfctn_mngr);
 
-  priv->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Photos"));
-  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->overview));
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->overview));
+  self->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Photos"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->overview));
+  gtk_stack_add_titled (GTK_STACK (self->stack), self->overview, "overview", name);
+  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->overview));
   g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
-  priv->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
-  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->collections));
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->collections, "collections", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->collections));
+  self->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->collections));
+  gtk_stack_add_titled (GTK_STACK (self->stack), self->collections, "collections", name);
+  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->collections));
   g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
-  priv->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
-  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->favorites));
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->favorites, "favorites", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->favorites));
+  self->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->favorites));
+  gtk_stack_add_titled (GTK_STACK (self->stack), self->favorites, "favorites", name);
+  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->favorites));
   g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
-  priv->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH, _("Search"));
-  gtk_stack_add_named (GTK_STACK (priv->stack), priv->search, "search");
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->search));
+  self->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH, _("Search"));
+  gtk_stack_add_named (GTK_STACK (self->stack), self->search, "search");
+  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->search));
   g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
-  priv->preview = photos_preview_view_new (GTK_OVERLAY (priv->stack_overlay));
-  gtk_stack_add_named (GTK_STACK (priv->stack), priv->preview, "preview");
+  self->preview = photos_preview_view_new (GTK_OVERLAY (self->stack_overlay));
+  gtk_stack_add_named (GTK_STACK (self->stack), self->preview, "preview");
 
-  priv->spinner_box = photos_spinner_box_new ();
-  gtk_overlay_add_overlay (GTK_OVERLAY (priv->stack_overlay), priv->spinner_box);
+  self->spinner_box = photos_spinner_box_new ();
+  gtk_overlay_add_overlay (GTK_OVERLAY (self->stack_overlay), self->spinner_box);
 
   /* TODO: SearchBar.Dropdown, …
    */
 
-  g_signal_connect_object (priv->stack,
+  g_signal_connect_object (self->stack,
                            "notify::visible-child",
                            G_CALLBACK (photos_embed_notify_visible_child),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->mode_cntrlr = g_object_ref (state->mode_cntrlr);
-  g_signal_connect_object (priv->mode_cntrlr,
+  self->mode_cntrlr = g_object_ref (state->mode_cntrlr);
+  g_signal_connect_object (self->mode_cntrlr,
                            "window-mode-changed",
                            G_CALLBACK (photos_embed_window_mode_changed),
                            self,
                            0);
-  g_signal_connect_object (priv->mode_cntrlr,
+  g_signal_connect_object (self->mode_cntrlr,
                            "fullscreen-changed",
                            G_CALLBACK (photos_embed_fullscreen_changed),
                            self,
                            0);
 
-  priv->trk_ovrvw_cntrlr = photos_tracker_overview_controller_dup_singleton ();
-  g_signal_connect_object (priv->trk_ovrvw_cntrlr,
+  self->trk_ovrvw_cntrlr = photos_tracker_overview_controller_dup_singleton ();
+  g_signal_connect_object (self->trk_ovrvw_cntrlr,
                            "query-status-changed",
                            G_CALLBACK (photos_embed_query_status_changed),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->item_mngr = g_object_ref (state->item_mngr);
-  g_signal_connect_object (priv->item_mngr,
+  self->item_mngr = g_object_ref (state->item_mngr);
+  g_signal_connect_object (self->item_mngr,
                            "active-collection-changed",
                            G_CALLBACK (photos_embed_active_collection_changed),
                            self,
                            0);
-  g_signal_connect_object (priv->item_mngr,
+  g_signal_connect_object (self->item_mngr,
                            "load-finished",
                            G_CALLBACK (photos_embed_load_finished),
                            self,
                            G_CONNECT_SWAPPED);
-  g_signal_connect_object (priv->item_mngr,
+  g_signal_connect_object (self->item_mngr,
                            "load-started",
                            G_CALLBACK (photos_embed_load_started),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->src_mngr = g_object_ref (state->src_mngr);
-  g_signal_connect_object (priv->src_mngr,
+  self->src_mngr = g_object_ref (state->src_mngr);
+  g_signal_connect_object (self->src_mngr,
                            "active-changed",
                            G_CALLBACK (photos_embed_search_changed),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->srch_mngr = g_object_ref (state->srch_typ_mngr);
-  g_signal_connect_object (priv->srch_mngr,
+  self->srch_mngr = g_object_ref (state->srch_typ_mngr);
+  g_signal_connect_object (self->srch_mngr,
                            "active-changed",
                            G_CALLBACK (photos_embed_search_changed),
                            self,
                            G_CONNECT_SWAPPED);
 
-  querying = photos_tracker_controller_get_query_status (priv->trk_ovrvw_cntrlr);
+  querying = photos_tracker_controller_get_query_status (self->trk_ovrvw_cntrlr);
   photos_embed_query_status_changed (self, querying);
 
-  priv->srch_cntrlr = g_object_ref (state->srch_cntrlr);
-  g_signal_connect_object (priv->srch_cntrlr,
+  self->srch_cntrlr = g_object_ref (state->srch_cntrlr);
+  g_signal_connect_object (self->srch_cntrlr,
                            "search-string-changed",
                            G_CALLBACK (photos_embed_search_changed),
                            self,
@@ -837,5 +807,5 @@ photos_embed_new (void)
 PhotosMainToolbar *
 photos_embed_get_main_toolbar (PhotosEmbed *self)
 {
-  return PHOTOS_MAIN_TOOLBAR (self->priv->toolbar);
+  return PHOTOS_MAIN_TOOLBAR (self->toolbar);
 }
