@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2015, 2016 Red Hat, Inc.
+ * Copyright © 2015 – 2016 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,34 +81,50 @@ photos_export_dialog_create_size_str (gint height, gint width, guint64 size)
 
 
 static void
-photos_export_dialog_show_size_options (PhotosExportDialog *self, gboolean progress)
+photos_export_dialog_show_size_options (PhotosExportDialog *self, gboolean size_options, gboolean progress)
 {
-  gdouble progress_opacity;
-  gdouble progress_opacity_invert;
+  GtkStyleContext *context;
+  const gchar *class_name;
+  const gchar *invert_class_name;
 
   gtk_widget_set_margin_bottom (self->dir_entry, 6);
   gtk_widget_set_margin_bottom (self->folder_name_label, 6);
 
-  progress_opacity = progress ? 1.0 : 0.0;
-  progress_opacity_invert = !progress ? 1.0 : 0.0;
+  class_name = progress ? "photos-fade-in" : "photos-fade-out";
+  invert_class_name = !progress ? "photos-fade-in" : "photos-fade-out";
 
   gtk_widget_show (self->progress_label);
-  gtk_widget_set_opacity (self->progress_label, progress_opacity);
+  context = gtk_widget_get_style_context (self->progress_label);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
+
+  class_name = size_options ? "photos-fade-in" : "photos-fade-out";
+  invert_class_name = !size_options ? "photos-fade-in" : "photos-fade-out";
 
   gtk_widget_show (self->full_label);
-  gtk_widget_set_opacity (self->full_label, progress_opacity_invert);
+  context = gtk_widget_get_style_context (self->full_label);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
 
   gtk_widget_show (self->full_button);
-  gtk_widget_set_opacity (self->full_button, progress_opacity_invert);
+  context = gtk_widget_get_style_context (self->full_button);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
 
   gtk_widget_show (self->reduced_button);
-  gtk_widget_set_opacity (self->reduced_button, progress_opacity_invert);
+  context = gtk_widget_get_style_context (self->reduced_button);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
 
   gtk_widget_show (self->reduced_label);
-  gtk_widget_set_opacity (self->reduced_label, progress_opacity_invert);
+  context = gtk_widget_get_style_context (self->reduced_label);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
 
   gtk_widget_show (self->size_label);
-  gtk_widget_set_opacity (self->size_label, progress_opacity_invert);
+  context = gtk_widget_get_style_context (self->size_label);
+  gtk_style_context_remove_class (context, invert_class_name);
+  gtk_style_context_add_class (context, class_name);
 }
 
 
@@ -118,15 +134,14 @@ photos_export_dialog_guess_sizes (GObject *source_object, GAsyncResult *res, gpo
   PhotosExportDialog *self;
   PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
   GError *error;
-  GeglRectangle bbox;
-  gboolean got_bbox_edited;
-  gchar *size_str;
-  gchar *size_str_markup;
+  gboolean success = TRUE;
   gsize sizes[2];
 
   error = NULL;
   if (!photos_base_item_save_guess_sizes_finish (item, res, &sizes[0], &sizes[1], &error))
     {
+      success = FALSE;
+
       if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
         {
           g_error_free (error);
@@ -136,39 +151,109 @@ photos_export_dialog_guess_sizes (GObject *source_object, GAsyncResult *res, gpo
         {
           g_warning ("Unable to guess sizes: %s", error->message);
           g_error_free (error);
-          goto out;
         }
     }
 
   self = PHOTOS_EXPORT_DIALOG (user_data);
 
-  got_bbox_edited = photos_base_item_get_bbox_edited (self->item, &bbox);
-  g_return_if_fail (got_bbox_edited);
-
-  size_str = photos_export_dialog_create_size_str (bbox.height, bbox.width, (guint64) sizes[0]);
-  size_str_markup = g_strdup_printf ("<small>%s</small>", size_str);
-  gtk_label_set_markup (GTK_LABEL (self->full_label), size_str_markup);
-  g_free (size_str);
-  g_free (size_str_markup);
-
-  if (self->reduced_zoom > 0.0)
+  if (success)
     {
-      gint reduced_height;
-      gint reduced_width;
-      gsize reduced_size;
+      GeglRectangle bbox;
+      gboolean got_bbox_edited;
+      gchar *size_str;
+      gchar *size_str_markup;
 
-      reduced_height = (gint) ((gdouble) bbox.height * self->reduced_zoom + 0.5);
-      reduced_width = (gint) ((gdouble) bbox.width * self->reduced_zoom + 0.5);
-      reduced_size = (gsize) (sizes[1] + (sizes[0] - sizes[1]) * (self->reduced_zoom - 0.5) / (1.0 - 0.5) + 0.5);
-      size_str = photos_export_dialog_create_size_str (reduced_height, reduced_width, (guint64) reduced_size);
+      got_bbox_edited = photos_base_item_get_bbox_edited (self->item, &bbox);
+      g_return_if_fail (got_bbox_edited);
+
+      size_str = photos_export_dialog_create_size_str (bbox.height, bbox.width, (guint64) sizes[0]);
       size_str_markup = g_strdup_printf ("<small>%s</small>", size_str);
-      gtk_label_set_markup (GTK_LABEL (self->reduced_label), size_str_markup);
+      gtk_label_set_markup (GTK_LABEL (self->full_label), size_str_markup);
       g_free (size_str);
       g_free (size_str_markup);
+
+      if (self->reduced_zoom > 0.0)
+        {
+          gint reduced_height;
+          gint reduced_width;
+          gsize reduced_size;
+
+          reduced_height = (gint) ((gdouble) bbox.height * self->reduced_zoom + 0.5);
+          reduced_width = (gint) ((gdouble) bbox.width * self->reduced_zoom + 0.5);
+          reduced_size = (gsize) (sizes[1]
+                                  + (sizes[0] - sizes[1]) * (self->reduced_zoom - 0.5) / (1.0 - 0.5)
+                                  + 0.5);
+          size_str = photos_export_dialog_create_size_str (reduced_height, reduced_width, (guint64) reduced_size);
+          size_str_markup = g_strdup_printf ("<small>%s</small>", size_str);
+          gtk_label_set_markup (GTK_LABEL (self->reduced_label), size_str_markup);
+          g_free (size_str);
+          g_free (size_str_markup);
+        }
+    }
+
+  photos_export_dialog_show_size_options (self, TRUE, FALSE);
+}
+
+
+static void
+photos_export_dialog_load (GObject *source_object, GAsyncResult *result, gpointer user_data)
+{
+  PhotosExportDialog *self;
+  PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
+  GError *error;
+  GeglNode *node = NULL;
+  gboolean success = TRUE;
+
+  error = NULL;
+  node = photos_base_item_load_finish (item, result, &error);
+  if (error != NULL)
+    {
+      success = FALSE;
+
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+          g_error_free (error);
+          goto out;
+        }
+      else
+        {
+          g_warning ("Unable to load the item: %s", error->message);
+          g_error_free (error);
+        }
+    }
+
+  self = PHOTOS_EXPORT_DIALOG (user_data);
+
+  photos_export_dialog_show_size_options (self, FALSE, FALSE);
+
+  if (success)
+    {
+      GeglRectangle bbox;
+      gboolean got_bbox_edited;
+      gint max_dimension;
+      guint i;
+
+      got_bbox_edited = photos_base_item_get_bbox_edited (self->item, &bbox);
+      g_return_if_fail (got_bbox_edited);
+
+      max_dimension = MAX (bbox.height, bbox.width);
+      for (i = 0; i < G_N_ELEMENTS (PIXEL_SIZES); i++)
+        {
+          if (max_dimension > PIXEL_SIZES[i])
+            {
+              self->reduced_zoom = (gdouble) PIXEL_SIZES[i] / (gdouble) max_dimension;
+              photos_export_dialog_show_size_options (self, FALSE, TRUE);
+              photos_base_item_save_guess_sizes_async (self->item,
+                                                       self->cancellable,
+                                                       photos_export_dialog_guess_sizes,
+                                                       self);
+              break;
+            }
+        }
     }
 
  out:
-  photos_export_dialog_show_size_options (self, FALSE);
+  g_clear_object (&node);
 }
 
 
@@ -189,29 +274,7 @@ photos_export_dialog_constructed (GObject *object)
   else
     {
       GDateTime *now;
-      GeglRectangle bbox;
-      gboolean got_bbox_edited;
       gchar *now_str;
-      gint max_dimension;
-      guint i;
-
-      got_bbox_edited = photos_base_item_get_bbox_edited (self->item, &bbox);
-      g_return_if_fail (got_bbox_edited);
-
-      max_dimension = MAX (bbox.height, bbox.width);
-      for (i = 0; i < G_N_ELEMENTS (PIXEL_SIZES); i++)
-        {
-          if (max_dimension > PIXEL_SIZES[i])
-            {
-              self->reduced_zoom = (gdouble) PIXEL_SIZES[i] / (gdouble) max_dimension;
-              photos_export_dialog_show_size_options (self, TRUE);
-              photos_base_item_save_guess_sizes_async (self->item,
-                                                       self->cancellable,
-                                                       photos_export_dialog_guess_sizes,
-                                                       self);
-              break;
-            }
-        }
 
       now = g_date_time_new_now_local ();
 
@@ -222,8 +285,11 @@ photos_export_dialog_constructed (GObject *object)
 
       gtk_entry_set_text (GTK_ENTRY (self->dir_entry), now_str);
 
-      g_free (now_str);
+      photos_export_dialog_show_size_options (self, FALSE, TRUE);
+      photos_base_item_load_async (self->item, self->cancellable, photos_export_dialog_load, self);
+
       g_date_time_unref (now);
+      g_free (now_str);
     }
 }
 
