@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2013 – 2016 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,8 +38,9 @@
 #include "photos-view-model.h"
 
 
-struct _PhotosPreviewNavButtonsPrivate
+struct _PhotosPreviewNavButtons
 {
+  GObject parent_instance;
   GAction *load_next;
   GAction *load_previous;
   GtkGesture *tap_gesture;
@@ -61,6 +62,11 @@ struct _PhotosPreviewNavButtonsPrivate
   gulong row_inserted_id;
 };
 
+struct _PhotosPreviewNavButtonsClass
+{
+  GObjectClass parent_class;
+};
+
 enum
 {
   PROP_0,
@@ -69,34 +75,33 @@ enum
 };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosPreviewNavButtons, photos_preview_nav_buttons, G_TYPE_OBJECT);
+G_DEFINE_TYPE (PhotosPreviewNavButtons, photos_preview_nav_buttons, G_TYPE_OBJECT);
 
 
 static void
 photos_preview_nav_buttons_delete (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GList *items = NULL;
   PhotosBaseItem *item;
   PhotosWindowMode mode;
 
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (mode != PHOTOS_WINDOW_MODE_PREVIEW)
     return;
 
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->item_mngr));
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
   if (item == NULL)
     return;
 
-  if (priv->enable_next)
-    g_action_activate (priv->load_next, NULL);
-  else if (priv->enable_prev)
-    g_action_activate (priv->load_previous, NULL);
+  if (self->enable_next)
+    g_action_activate (self->load_next, NULL);
+  else if (self->enable_prev)
+    g_action_activate (self->load_previous, NULL);
   else
-    photos_mode_controller_go_back (priv->mode_cntrlr);
+    photos_mode_controller_go_back (self->mode_cntrlr);
 
   items = g_list_prepend (items, g_object_ref (item));
-  photos_base_manager_remove_object (priv->item_mngr, G_OBJECT (item));
+  photos_base_manager_remove_object (self->item_mngr, G_OBJECT (item));
   photos_delete_notification_new (items);
   g_list_free_full (items, g_object_unref);
 }
@@ -105,9 +110,7 @@ photos_preview_nav_buttons_delete (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_fade_in_button (PhotosPreviewNavButtons *self, GtkWidget *widget)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  if (priv->model == NULL || !gtk_tree_row_reference_valid (priv->current_row))
+  if (self->model == NULL || !gtk_tree_row_reference_valid (self->current_row))
     return;
 
   gtk_widget_show_all (widget);
@@ -143,42 +146,41 @@ photos_preview_nav_buttons_fade_out_button (PhotosPreviewNavButtons *self, GtkWi
 static void
 photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkTreeIter iter;
   GtkTreeIter tmp;
   GtkTreePath *current_path = NULL;
 
-  if (priv->model == NULL
-      || !gtk_tree_row_reference_valid (priv->current_row)
-      || !priv->visible)
+  if (self->model == NULL
+      || !gtk_tree_row_reference_valid (self->current_row)
+      || !self->visible)
     {
-      priv->enable_prev = FALSE;
-      priv->enable_next = FALSE;
+      self->enable_prev = FALSE;
+      self->enable_next = FALSE;
       goto out;
     }
 
-  current_path = gtk_tree_row_reference_get_path (priv->current_row);
-  gtk_tree_model_get_iter (priv->model, &iter, current_path);
+  current_path = gtk_tree_row_reference_get_path (self->current_row);
+  gtk_tree_model_get_iter (self->model, &iter, current_path);
 
   tmp = iter;
-  priv->enable_prev = gtk_tree_model_iter_previous (priv->model, &tmp);
+  self->enable_prev = gtk_tree_model_iter_previous (self->model, &tmp);
 
   tmp = iter;
-  priv->enable_next = gtk_tree_model_iter_next (priv->model, &tmp);
+  self->enable_next = gtk_tree_model_iter_next (self->model, &tmp);
 
  out:
-  if (priv->visible_internal && priv->enable_next)
-    photos_preview_nav_buttons_fade_in_button (self, priv->next_widget);
+  if (self->visible_internal && self->enable_next)
+    photos_preview_nav_buttons_fade_in_button (self, self->next_widget);
   else
-    photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+    photos_preview_nav_buttons_fade_out_button (self, self->next_widget);
 
-  if (priv->visible_internal && priv->enable_prev)
-    photos_preview_nav_buttons_fade_in_button (self, priv->prev_widget);
+  if (self->visible_internal && self->enable_prev)
+    photos_preview_nav_buttons_fade_in_button (self, self->prev_widget);
   else
-    photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
+    photos_preview_nav_buttons_fade_out_button (self, self->prev_widget);
 
-  g_simple_action_set_enabled (G_SIMPLE_ACTION (priv->load_next), priv->enable_next);
-  g_simple_action_set_enabled (G_SIMPLE_ACTION (priv->load_previous), priv->enable_prev);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->load_next), self->enable_next);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->load_previous), self->enable_prev);
 
   g_clear_pointer (&current_path, (GDestroyNotify) gtk_tree_path_free);
 }
@@ -187,10 +189,8 @@ photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
 static gboolean
 photos_preview_nav_buttons_auto_hide (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  priv->auto_hide_id = 0;
-  priv->visible_internal = FALSE;
+  self->auto_hide_id = 0;
+  self->visible_internal = FALSE;
   photos_preview_nav_buttons_update_visibility (self);
   return G_SOURCE_REMOVE;
 }
@@ -199,13 +199,11 @@ photos_preview_nav_buttons_auto_hide (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_unqueue_auto_hide (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  if (priv->auto_hide_id == 0)
+  if (self->auto_hide_id == 0)
     return;
 
-  g_source_remove (priv->auto_hide_id);
-  priv->auto_hide_id = 0;
+  g_source_remove (self->auto_hide_id);
+  self->auto_hide_id = 0;
 }
 
 
@@ -220,10 +218,8 @@ photos_preview_nav_buttons_enter_notify (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_queue_auto_hide (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
   photos_preview_nav_buttons_unqueue_auto_hide (self);
-  priv->auto_hide_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
+  self->auto_hide_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
                                                    2,
                                                    (GSourceFunc) photos_preview_nav_buttons_auto_hide,
                                                    g_object_ref (self),
@@ -242,10 +238,8 @@ photos_preview_nav_buttons_leave_notify (PhotosPreviewNavButtons *self)
 static gboolean
 photos_preview_nav_buttons_motion_notify_timeout (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  priv->motion_id = 0;
-  priv->visible_internal = TRUE;
+  self->motion_id = 0;
+  self->visible_internal = TRUE;
   photos_preview_nav_buttons_update_visibility (self);
   photos_preview_nav_buttons_queue_auto_hide (self);
   return G_SOURCE_REMOVE;
@@ -255,11 +249,10 @@ photos_preview_nav_buttons_motion_notify_timeout (PhotosPreviewNavButtons *self)
 static gboolean
 photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self, GdkEventMotion *event)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GdkDevice *device;
   GdkInputSource input_source;
 
-  if (priv->motion_id != 0)
+  if (self->motion_id != 0)
     return FALSE;
 
   device = gdk_event_get_source_device ((GdkEvent *) event);
@@ -267,7 +260,7 @@ photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self, GdkEven
   if (input_source == GDK_SOURCE_TOUCHSCREEN)
     return FALSE;
 
-  priv->motion_id = g_idle_add_full (G_PRIORITY_DEFAULT,
+  self->motion_id = g_idle_add_full (G_PRIORITY_DEFAULT,
                                      (GSourceFunc) photos_preview_nav_buttons_motion_notify_timeout,
                                      g_object_ref (self),
                                      g_object_unref);
@@ -278,10 +271,8 @@ photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self, GdkEven
 static void
 photos_preview_nav_buttons_multi_press_released (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  gtk_gesture_set_state (GTK_GESTURE (priv->tap_gesture), GTK_EVENT_SEQUENCE_CLAIMED);
-  priv->visible_internal = !priv->visible_internal;
+  gtk_gesture_set_state (GTK_GESTURE (self->tap_gesture), GTK_EVENT_SEQUENCE_CLAIMED);
+  self->visible_internal = !self->visible_internal;
   photos_preview_nav_buttons_unqueue_auto_hide (self);
   photos_preview_nav_buttons_update_visibility (self);
 }
@@ -290,7 +281,7 @@ photos_preview_nav_buttons_multi_press_released (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_multi_press_stopped (PhotosPreviewNavButtons *self)
 {
-  gtk_gesture_set_state (GTK_GESTURE (self->priv->tap_gesture), GTK_EVENT_SEQUENCE_DENIED);
+  gtk_gesture_set_state (GTK_GESTURE (self->tap_gesture), GTK_EVENT_SEQUENCE_DENIED);
 }
 
 
@@ -304,25 +295,24 @@ photos_preview_nav_buttons_row_changed (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_set_active_path (PhotosPreviewNavButtons *self, GtkTreePath *current_path)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkTreeIter child_iter;
   GtkTreeIter iter;
   GtkTreeModel *child_model;
   PhotosBaseItem *item;
   gchar *id;
 
-  if (!gtk_tree_model_get_iter (priv->model, &iter, current_path))
+  if (!gtk_tree_model_get_iter (self->model, &iter, current_path))
     return;
 
-  g_clear_pointer (&priv->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
-  priv->current_row = gtk_tree_row_reference_new (priv->model, current_path);
+  g_clear_pointer (&self->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
+  self->current_row = gtk_tree_row_reference_new (self->model, current_path);
 
-  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (priv->model), &child_iter, &iter);
-  child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (priv->model));
+  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (self->model), &child_iter, &iter);
+  child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (self->model));
   gtk_tree_model_get (child_model, &child_iter, PHOTOS_VIEW_MODEL_URN, &id, -1);
 
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (priv->item_mngr, id));
-  photos_base_manager_set_active_object (priv->item_mngr, G_OBJECT (item));
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (self->item_mngr, id));
+  photos_base_manager_set_active_object (self->item_mngr, G_OBJECT (item));
 
   g_free (id);
 }
@@ -331,13 +321,12 @@ photos_preview_nav_buttons_set_active_path (PhotosPreviewNavButtons *self, GtkTr
 static void
 photos_preview_nav_buttons_next (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkTreePath *current_path;
 
-  if (!priv->enable_next)
+  if (!self->enable_next)
     return;
 
-  current_path = gtk_tree_row_reference_get_path (priv->current_row);
+  current_path = gtk_tree_row_reference_get_path (self->current_row);
   gtk_tree_path_next (current_path);
   photos_preview_nav_buttons_set_active_path (self, current_path);
   photos_preview_nav_buttons_update_visibility (self);
@@ -348,13 +337,12 @@ photos_preview_nav_buttons_next (PhotosPreviewNavButtons *self)
 static void
 photos_preview_nav_buttons_previous (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkTreePath *current_path;
 
-  if (!priv->enable_prev)
+  if (!self->enable_prev)
     return;
 
-  current_path = gtk_tree_row_reference_get_path (priv->current_row);
+  current_path = gtk_tree_row_reference_get_path (self->current_row);
   gtk_tree_path_prev (current_path);
   photos_preview_nav_buttons_set_active_path (self, current_path);
   photos_preview_nav_buttons_update_visibility (self);
@@ -366,14 +354,13 @@ static void
 photos_preview_nav_buttons_dispose (GObject *object)
 {
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
-  g_clear_object (&priv->tap_gesture);
-  g_clear_object (&priv->model);
-  g_clear_object (&priv->next_widget);
-  g_clear_object (&priv->prev_widget);
-  g_clear_object (&priv->item_mngr);
-  g_clear_object (&priv->mode_cntrlr);
+  g_clear_object (&self->tap_gesture);
+  g_clear_object (&self->model);
+  g_clear_object (&self->next_widget);
+  g_clear_object (&self->prev_widget);
+  g_clear_object (&self->item_mngr);
+  g_clear_object (&self->mode_cntrlr);
 
   G_OBJECT_CLASS (photos_preview_nav_buttons_parent_class)->dispose (object);
 }
@@ -383,9 +370,8 @@ static void
 photos_preview_nav_buttons_finalize (GObject *object)
 {
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
-  g_clear_pointer (&priv->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
+  g_clear_pointer (&self->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
 
   G_OBJECT_CLASS (photos_preview_nav_buttons_parent_class)->finalize (object);
 }
@@ -395,20 +381,19 @@ static void
 photos_preview_nav_buttons_constructed (GObject *object)
 {
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkStyleContext *context;
   GtkWidget *button;
   GtkWidget *image;
 
   G_OBJECT_CLASS (photos_preview_nav_buttons_parent_class)->constructed (object);
 
-  priv->prev_widget = g_object_ref_sink (gtk_revealer_new ());
-  gtk_widget_set_halign (priv->prev_widget, GTK_ALIGN_START);
-  gtk_widget_set_margin_start (priv->prev_widget, 30);
-  gtk_widget_set_margin_end (priv->prev_widget, 30);
-  gtk_widget_set_valign (priv->prev_widget, GTK_ALIGN_CENTER);
-  gtk_revealer_set_transition_type (GTK_REVEALER (priv->prev_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
-  gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay), priv->prev_widget);
+  self->prev_widget = g_object_ref_sink (gtk_revealer_new ());
+  gtk_widget_set_halign (self->prev_widget, GTK_ALIGN_START);
+  gtk_widget_set_margin_start (self->prev_widget, 30);
+  gtk_widget_set_margin_end (self->prev_widget, 30);
+  gtk_widget_set_valign (self->prev_widget, GTK_ALIGN_CENTER);
+  gtk_revealer_set_transition_type (GTK_REVEALER (self->prev_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
+  gtk_overlay_add_overlay (GTK_OVERLAY (self->overlay), self->prev_widget);
 
   image = gtk_image_new_from_icon_name (PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC, GTK_ICON_SIZE_INVALID);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
@@ -418,7 +403,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_actionable_set_action_name (GTK_ACTIONABLE (button), "app.load-previous");
   context = gtk_widget_get_style_context (button);
   gtk_style_context_add_class (context, "osd");
-  gtk_container_add (GTK_CONTAINER (priv->prev_widget), button);
+  gtk_container_add (GTK_CONTAINER (self->prev_widget), button);
   g_signal_connect_swapped (button,
                             "enter-notify-event",
                             G_CALLBACK (photos_preview_nav_buttons_enter_notify),
@@ -428,13 +413,13 @@ photos_preview_nav_buttons_constructed (GObject *object)
                             G_CALLBACK (photos_preview_nav_buttons_leave_notify),
                             self);
 
-  priv->next_widget = g_object_ref_sink (gtk_revealer_new ());
-  gtk_widget_set_halign (priv->next_widget, GTK_ALIGN_END);
-  gtk_widget_set_margin_start (priv->next_widget, 30);
-  gtk_widget_set_margin_end (priv->next_widget, 30);
-  gtk_widget_set_valign (priv->next_widget, GTK_ALIGN_CENTER);
-  gtk_revealer_set_transition_type (GTK_REVEALER (priv->next_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
-  gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay), priv->next_widget);
+  self->next_widget = g_object_ref_sink (gtk_revealer_new ());
+  gtk_widget_set_halign (self->next_widget, GTK_ALIGN_END);
+  gtk_widget_set_margin_start (self->next_widget, 30);
+  gtk_widget_set_margin_end (self->next_widget, 30);
+  gtk_widget_set_valign (self->next_widget, GTK_ALIGN_CENTER);
+  gtk_revealer_set_transition_type (GTK_REVEALER (self->next_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
+  gtk_overlay_add_overlay (GTK_OVERLAY (self->overlay), self->next_widget);
 
   image = gtk_image_new_from_icon_name (PHOTOS_ICON_GO_NEXT_SYMBOLIC, GTK_ICON_SIZE_INVALID);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
@@ -444,7 +429,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_actionable_set_action_name (GTK_ACTIONABLE (button), "app.load-next");
   context = gtk_widget_get_style_context (button);
   gtk_style_context_add_class (context, "osd");
-  gtk_container_add (GTK_CONTAINER (priv->next_widget), button);
+  gtk_container_add (GTK_CONTAINER (self->next_widget), button);
   g_signal_connect_swapped (button,
                             "enter-notify-event",
                             G_CALLBACK (photos_preview_nav_buttons_enter_notify),
@@ -454,25 +439,25 @@ photos_preview_nav_buttons_constructed (GObject *object)
                             G_CALLBACK (photos_preview_nav_buttons_leave_notify),
                             self);
 
-  g_signal_connect_swapped (priv->overlay,
+  g_signal_connect_swapped (self->overlay,
                             "motion-notify-event",
                             G_CALLBACK (photos_preview_nav_buttons_motion_notify),
                             self);
 
-  priv->tap_gesture = gtk_gesture_multi_press_new (priv->preview_view);
-  gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (priv->tap_gesture), TRUE);
-  g_signal_connect_swapped (priv->tap_gesture,
+  self->tap_gesture = gtk_gesture_multi_press_new (self->preview_view);
+  gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (self->tap_gesture), TRUE);
+  g_signal_connect_swapped (self->tap_gesture,
                             "released",
                             G_CALLBACK (photos_preview_nav_buttons_multi_press_released),
                             self);
-  g_signal_connect_swapped (priv->tap_gesture,
+  g_signal_connect_swapped (self->tap_gesture,
                             "stopped",
                             G_CALLBACK (photos_preview_nav_buttons_multi_press_stopped),
                             self);
 
   /* We will not need them any more */
-  priv->overlay = NULL;
-  priv->preview_view = NULL;
+  self->overlay = NULL;
+  self->preview_view = NULL;
 }
 
 
@@ -480,16 +465,15 @@ static void
 photos_preview_nav_buttons_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
   switch (prop_id)
     {
     case PROP_OVERLAY:
-      priv->overlay = GTK_WIDGET (g_value_get_object (value)); /* overlay is owned by preview_view */
+      self->overlay = GTK_WIDGET (g_value_get_object (value)); /* overlay is owned by preview_view */
       break;
 
     case PROP_PREVIEW_VIEW:
-      priv->preview_view = GTK_WIDGET (g_value_get_object (value)); /* self is owned by preview_view */
+      self->preview_view = GTK_WIDGET (g_value_get_object (value)); /* self is owned by preview_view */
       break;
 
     default:
@@ -502,33 +486,29 @@ photos_preview_nav_buttons_set_property (GObject *object, guint prop_id, const G
 static void
 photos_preview_nav_buttons_init (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv;
   GAction *action;
   GApplication *app;
   PhotosSearchContextState *state;
 
-  self->priv = photos_preview_nav_buttons_get_instance_private (self);
-  priv = self->priv;
-
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  priv->load_next = g_action_map_lookup_action (G_ACTION_MAP (app), "load-next");
-  g_signal_connect_object (priv->load_next,
+  self->load_next = g_action_map_lookup_action (G_ACTION_MAP (app), "load-next");
+  g_signal_connect_object (self->load_next,
                            "activate",
                            G_CALLBACK (photos_preview_nav_buttons_next),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->load_previous = g_action_map_lookup_action (G_ACTION_MAP (app), "load-previous");
-  g_signal_connect_object (priv->load_previous,
+  self->load_previous = g_action_map_lookup_action (G_ACTION_MAP (app), "load-previous");
+  g_signal_connect_object (self->load_previous,
                            "activate",
                            G_CALLBACK (photos_preview_nav_buttons_previous),
                            self,
                            G_CONNECT_SWAPPED);
 
-  priv->item_mngr = g_object_ref (state->item_mngr);
-  priv->mode_cntrlr = g_object_ref (state->mode_cntrlr);
+  self->item_mngr = g_object_ref (state->item_mngr);
+  self->mode_cntrlr = g_object_ref (state->mode_cntrlr);
 
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "delete");
   g_signal_connect_object (action,
@@ -580,10 +560,8 @@ photos_preview_nav_buttons_new (PhotosPreviewView *preview_view, GtkOverlay *ove
 void
 photos_preview_nav_buttons_hide (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  priv->visible = FALSE;
-  priv->visible_internal = FALSE;
+  self->visible = FALSE;
+  self->visible_internal = FALSE;
   photos_preview_nav_buttons_update_visibility (self);
 }
 
@@ -593,44 +571,42 @@ photos_preview_nav_buttons_set_model (PhotosPreviewNavButtons *self,
                                       GtkTreeModel *child_model,
                                       GtkTreePath *current_child_path)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  if (priv->row_deleted_id != 0)
+  if (self->row_deleted_id != 0)
     {
-      g_signal_handler_disconnect (priv->model, priv->row_deleted_id);
-      priv->row_deleted_id = 0;
+      g_signal_handler_disconnect (self->model, self->row_deleted_id);
+      self->row_deleted_id = 0;
     }
 
-  if (priv->row_inserted_id != 0)
+  if (self->row_inserted_id != 0)
     {
-      g_signal_handler_disconnect (priv->model, priv->row_inserted_id);
-      priv->row_inserted_id = 0;
+      g_signal_handler_disconnect (self->model, self->row_inserted_id);
+      self->row_inserted_id = 0;
     }
 
-  g_clear_object (&priv->model);
+  g_clear_object (&self->model);
 
   if (child_model != NULL)
     {
-      priv->model = photos_preview_model_new (child_model);
-      priv->row_deleted_id = g_signal_connect_swapped (priv->model,
+      self->model = photos_preview_model_new (child_model);
+      self->row_deleted_id = g_signal_connect_swapped (self->model,
                                                        "row-deleted",
                                                        G_CALLBACK (photos_preview_nav_buttons_row_changed),
                                                        self);
-      priv->row_inserted_id = g_signal_connect_swapped (priv->model,
+      self->row_inserted_id = g_signal_connect_swapped (self->model,
                                                         "row-inserted",
                                                         G_CALLBACK (photos_preview_nav_buttons_row_changed),
                                                         self);
     }
 
-  g_clear_pointer (&priv->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
+  g_clear_pointer (&self->current_row, (GDestroyNotify) gtk_tree_row_reference_free);
 
   if (child_model != NULL && current_child_path != NULL)
     {
       GtkTreePath *current_path;
 
-      current_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (priv->model),
+      current_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (self->model),
                                                                        current_child_path);
-      priv->current_row = gtk_tree_row_reference_new (priv->model, current_path);
+      self->current_row = gtk_tree_row_reference_new (self->model, current_path);
       gtk_tree_path_free (current_path);
     }
 }
@@ -639,10 +615,8 @@ photos_preview_nav_buttons_set_model (PhotosPreviewNavButtons *self,
 void
 photos_preview_nav_buttons_show (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  priv->visible = TRUE;
-  priv->visible_internal = TRUE;
+  self->visible = TRUE;
+  self->visible_internal = TRUE;
   photos_preview_nav_buttons_update_visibility (self);
   photos_preview_nav_buttons_queue_auto_hide (self);
 }
